@@ -8,7 +8,7 @@ use warnings;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2022-05-08'; # DATE
 our $DIST = 'Regexp-Pattern-Filename-Media-WhatsApp'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 our %RE;
 
@@ -18,6 +18,7 @@ $RE{filename_video_whatsapp} = {
                   (?:IMG-[0-9]{8}-WA[0-9]{4,}\.(?:JPG|jpg))|
                   (?:VID-[0-9]{8}-WA[0-9]{4,}\.(?:MP4|mp4))
               )\z/x,
+    tags => ['anchored'],
     examples => [
         {str=>'foo.jpg', matches=>0, summary=>'No pattern'},
         {str=>'foo.mp4', matches=>0, summary=>'No pattern'},
@@ -43,7 +44,7 @@ Regexp::Pattern::Filename::Media::WhatsApp - Media (video, image) filename saved
 
 =head1 VERSION
 
-This document describes version 0.002 of Regexp::Pattern::Filename::Media::WhatsApp (from Perl distribution Regexp-Pattern-Filename-Media-WhatsApp), released on 2022-05-08.
+This document describes version 0.003 of Regexp::Pattern::Filename::Media::WhatsApp (from Perl distribution Regexp-Pattern-Filename-Media-WhatsApp), released on 2022-05-08.
 
 =head1 SYNOPSIS
 
@@ -67,6 +68,8 @@ Using the pattern(s) directly:
 
 =item * filename_video_whatsapp
 
+Tags: anchored
+
 Media (video, image) filename saved by WhatsApp.
 
 Examples:
